@@ -40,7 +40,7 @@ fn get() {
 fn get_value() {
     let args = Arguments(vec!["onearg".to_string(), "twoargs".to_string(), "threeargs".to_string(), "fourargs".to_string()]);
     assert_eq!(args.get_value("onearg").unwrap(), "twoargs");
-    assert_eq!(args.get_value("threeargs").unwrap(), "fourargs");
+    assert_eq!(args.get_value("ThreeArgs").unwrap(), "fourargs");
     assert_eq!(args.get_value("fiveargs").unwrap_or(&"failed".to_string()), "failed");
 }
 
@@ -48,10 +48,26 @@ fn get_value() {
 fn get_value_case_sensitive() {
     let args = Arguments(vec!["onearg".to_string(), "twoargs".to_string(), "threeargs".to_string(), "fourargs".to_string()]);
     assert_eq!(args.get_value_case_sensitive("onearg").unwrap(), "twoargs");
-    assert_eq!(args.get_value_case_sensitive("Threeargs").unwrap_or(&"failed".to_string()), "failed");
+    assert_eq!(args.get_value_case_sensitive("ThreeArgs").unwrap_or(&"failed".to_string()), "failed");
     assert_eq!(args.get_value_case_sensitive("fiveargs").unwrap_or(&"failed".to_string()), "failed");
 }
 
+#[test]
+fn get_index() {
+    let args = Arguments(vec!["onearg".to_string(), "twoargs".to_string(), "threeargs".to_string(), "fourargs".to_string()]);
+    assert_eq!(args.get_index("onearg"), Some(0));
+    assert_eq!(args.get_index("oneArg"), Some(0));
+    assert_eq!(args.get_index("None"), None);
+}
+
+#[test]
+fn get_index_case_sensitive() {
+    let args = Arguments(vec!["onearg".to_string(), "twoargs".to_string(), "threeargs".to_string(), "fourargs".to_string()]);
+    assert_eq!(args.get_index_case_sensitive("onearg"), Some(0));
+    assert_eq!(args.get_index_case_sensitive("oneArg"), None);
+    assert_eq!(args.get_index_case_sensitive("None"), None);
+}
+
 #[test]
 fn exist() {
     let args = Arguments(vec!["onearg".to_string(), "twoargs".to_string()]);
